/v1/projects/{project_id}/dynamips/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/start_capture — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Dynamips vm »

# /v1/projects/{project_id}/dynamips/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/start_capture

Contents

- /v1/projects/{project_id}/dynamips/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/start_capture
  - POST /v1/projects/{project_id}/dynamips/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/start_capture
    - Parameters
    - Response status codes
    - Input

## POST /v1/projects/{project_id}/dynamips/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/start_capture

Start a packet capture on a Dynamips VM instance

### Parameters

- adapter_number: Adapter to start a packet capture
- port_number: Port on the adapter
- vm_id: UUID for the instance
- project_id: UUID for the project

### Response status codes

- 200: Capture started
- 400: Invalid request
- 404: Instance doesn’t exist

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
capture_file_name | ✔ | string | Capture file name
data_link_type | ✔ | string | PCAP data link type

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Dynamips vm »